=== modified file 'cloud_deploy.py'
--- cloud_deploy.py	2014-09-29 18:00:46 +0000
+++ cloud_deploy.py	2014-11-11 00:58:39 +0000
@@ -12,9 +12,11 @@
 from jujupy import (
     CannotConnectEnv,
     Environment,
+)
+from substrate import (
     start_libvirt_domain,
     stop_libvirt_domain,
-    verify_libvirt_domain_running,
+    verify_libvirt_domain,
 )
 
 
@@ -32,7 +34,7 @@
             name, URI = machine.split('@')
             # Record already running domains, so they can be left running,
             # if already running; otherwise start them.
-            if verify_libvirt_domain_running(URI, name):
+            if verify_libvirt_domain(URI, name, 'running'):
                 running_domains = {machine: True}
             else:
                 running_domains = {machine: False}

=== modified file 'deploy_stack.py'
--- deploy_stack.py	2014-11-10 19:39:33 +0000
+++ deploy_stack.py	2014-11-11 00:58:39 +0000
@@ -24,9 +24,11 @@
     bootstrap_from_env,
     Environment,
     get_local_root,
+)
+from substrate import (
     start_libvirt_domain,
     stop_libvirt_domain,
-    verify_libvirt_domain_running,
+    verify_libvirt_domain,
 )
 from utility import (
     PortTimeoutError,
@@ -395,7 +397,7 @@
                 name, URI = machine.split('@')
                 # Record already running domains, so they can be left running,
                 # when finished with the test.
-                if verify_libvirt_domain_running(URI, name):
+                if verify_libvirt_domain(URI, name, 'running'):
                     running_domains = {machine: True}
                     logging.info("%s is already running" % name)
                 else:

=== modified file 'jujupy.py'
--- jujupy.py	2014-11-11 00:04:52 +0000
+++ jujupy.py	2014-11-11 00:58:39 +0000
@@ -12,7 +12,6 @@
 import subprocess
 import sys
 import tempfile
-from time import sleep
 
 import yaml
 
@@ -588,72 +587,3 @@
             continue
         value_listing.append('%s: %s' % (value, ', '.join(entries)))
     return ' | '.join(value_listing)
-
-
-def start_libvirt_domain(URI, domain):
-    """Call virsh to start the domain.
-
-    @Parms URI: The address of the libvirt service.
-    @Parm domain: The name of the domain.
-    """
-
-    command = ['virsh', '-c', URI, 'start', domain]
-    try:
-        subprocess.check_output(command, stderr=subprocess.STDOUT)
-    except subprocess.CalledProcessError as e:
-        if 'already active' in e.output:
-            return '%s is already running; nothing to do.' % domain
-        raise Exception('%s failed:\n %s' % (command, e.output))
-    sleep(30)
-    for ignored in until_timeout(120):
-        if verify_libvirt_domain(URI, domain, 'running'):
-            return "%s is now running" % domain
-    raise Exception('libvirt domain %s did not start.' % domain)
-
-
-def stop_libvirt_domain(URI, domain):
-    """Call virsh to shutdown the domain.
-
-    @Parms URI: The address of the libvirt service.
-    @Parm domain: The name of the domain.
-    """
-
-    command = ['virsh', '-c', URI, 'shutdown', domain]
-    try:
-        subprocess.check_output(command, stderr=subprocess.STDOUT)
-    except subprocess.CalledProcessError as e:
-        if 'domain is not running' in e.output:
-            return ('%s is not running; nothing to do.' % domain)
-        raise Exception('%s failed:\n %s' % (command, e.output))
-    sleep(30)
-    for ignored in until_timeout(120):
-        if verify_libvirt_domain(URI, domain, 'shut off'):
-            return "%s is now shut off" % domain
-    raise Exception('libvirt domain %s is not shut off.' % domain)
-
-
-def verify_libvirt_domain(URI, domain, state="running"):
-    """Returns a bool based on if the domain is in the given state.
-
-    @Parms URI: The address of the libvirt service.
-    @Parm domain: The name of the domain.
-    @Parm state: The state to verify (e.g. "running or "shut off").
-    """
-
-    dom_status = get_libvirt_domstate(URI, domain)
-    return True if state in dom_status else False
-
-
-def get_libvirt_domstate(URI, domain):
-    """Call virsh to get the state of the given domain.
-
-    @Parms URI: The address of the libvirt service.
-    @Parm domain: The name of the domain.
-    """
-
-    command = ['virsh', '-c', URI, 'domstate', domain]
-    try:
-        sub_output = subprocess.check_output(command)
-    except subprocess.CalledProcessError:
-        raise Exception('%s failed' % command)
-    return sub_output

=== modified file 'start_libvirt_domain.py'
--- start_libvirt_domain.py	2014-11-11 00:03:11 +0000
+++ start_libvirt_domain.py	2014-11-11 00:58:39 +0000
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 from argparse import ArgumentParser
-from jujupy import start_libvirt_domain
+from substrate import start_libvirt_domain
 
 
 def main():

=== modified file 'stop_libvirt_domain.py'
--- stop_libvirt_domain.py	2014-11-11 00:03:11 +0000
+++ stop_libvirt_domain.py	2014-11-11 00:58:39 +0000
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 from argparse import ArgumentParser
-from jujupy import stop_libvirt_domain
+from substrate import stop_libvirt_domain
 
 
 def main():

=== modified file 'substrate.py'
--- substrate.py	2014-11-10 15:53:47 +0000
+++ substrate.py	2014-11-11 00:58:39 +0000
@@ -1,11 +1,15 @@
 import os
 import subprocess
+from time import sleep
 
 from jujuconfig import (
     get_euca_env,
     translate_to_env,
     )
-from utility import print_now
+from utility import (
+    print_now,
+    until_timeout,
+)
 
 
 def terminate_instances(env, instance_ids):
@@ -25,3 +29,72 @@
         return
     print_now("Deleting %s." % ', '.join(instance_ids))
     subprocess.check_call(command_args, env=environ)
+
+
+def start_libvirt_domain(URI, domain):
+    """Call virsh to start the domain.
+
+    @Parms URI: The address of the libvirt service.
+    @Parm domain: The name of the domain.
+    """
+
+    command = ['virsh', '-c', URI, 'start', domain]
+    try:
+        subprocess.check_output(command, stderr=subprocess.STDOUT)
+    except subprocess.CalledProcessError as e:
+        if 'already active' in e.output:
+            return '%s is already running; nothing to do.' % domain
+        raise Exception('%s failed:\n %s' % (command, e.output))
+    sleep(30)
+    for ignored in until_timeout(120):
+        if verify_libvirt_domain(URI, domain, 'running'):
+            return "%s is now running" % domain
+    raise Exception('libvirt domain %s did not start.' % domain)
+
+
+def stop_libvirt_domain(URI, domain):
+    """Call virsh to shutdown the domain.
+
+    @Parms URI: The address of the libvirt service.
+    @Parm domain: The name of the domain.
+    """
+
+    command = ['virsh', '-c', URI, 'shutdown', domain]
+    try:
+        subprocess.check_output(command, stderr=subprocess.STDOUT)
+    except subprocess.CalledProcessError as e:
+        if 'domain is not running' in e.output:
+            return ('%s is not running; nothing to do.' % domain)
+        raise Exception('%s failed:\n %s' % (command, e.output))
+    sleep(30)
+    for ignored in until_timeout(120):
+        if verify_libvirt_domain(URI, domain, 'shut off'):
+            return "%s is now shut off" % domain
+    raise Exception('libvirt domain %s is not shut off.' % domain)
+
+
+def verify_libvirt_domain(URI, domain, state='running'):
+    """Returns a bool based on if the domain is in the given state.
+
+    @Parms URI: The address of the libvirt service.
+    @Parm domain: The name of the domain.
+    @Parm state: The state to verify (e.g. "running or "shut off").
+    """
+
+    dom_status = get_libvirt_domstate(URI, domain)
+    return True if state in dom_status else False
+
+
+def get_libvirt_domstate(URI, domain):
+    """Call virsh to get the state of the given domain.
+
+    @Parms URI: The address of the libvirt service.
+    @Parm domain: The name of the domain.
+    """
+
+    command = ['virsh', '-c', URI, 'domstate', domain]
+    try:
+        sub_output = subprocess.check_output(command)
+    except subprocess.CalledProcessError:
+        raise Exception('%s failed' % command)
+    return sub_output

=== modified file 'test_jujupy.py'
--- test_jujupy.py	2014-11-10 17:56:48 +0000
+++ test_jujupy.py	2014-11-11 00:58:39 +0000
@@ -9,7 +9,6 @@
 from unittest import TestCase
 
 from mock import (
-    ANY,
     call,
     MagicMock,
     patch,
@@ -26,17 +25,12 @@
     EnvJujuClient,
     ErroredUnit,
     format_listing,
-    get_libvirt_domstate,
     get_local_root,
     JujuClientDevel,
     SimpleEnvironment,
-    start_libvirt_domain,
     Status,
-    stop_libvirt_domain,
     temp_bootstrap_env,
     uniquify_local,
-    verify_libvirt_domain_running,
-    verify_libvirt_domain_shut_off,
 )
 from utility import (
     scoped_environ,
@@ -1364,62 +1358,3 @@
         result = format_listing(
             {'1': ['a', 'b'], '2': ['c'], 'expected': ['d']}, 'expected')
         self.assertEqual('1: a, b | 2: c', result)
-
-
-class TestLibvirt(TestCase):
-
-    def test_start_libvirt_domain(self):
-        URI = 'qemu+ssh://someHost/system'
-        dom_name = 'fido'
-        with patch('subprocess.check_output',
-                   return_value='running') as mock_sp:
-            with patch('jujupy.sleep'):
-                start_libvirt_domain(URI, dom_name)
-        mock_sp.assert_any_call(['virsh', '-c', URI, 'start', dom_name],
-                                stderr=ANY)
-
-    def test_stop_libvirt_domain(self):
-        URI = 'qemu+ssh://someHost/system'
-        dom_name = 'fido'
-        with patch('subprocess.check_output',
-                   return_value='shut off') as mock_sp:
-            with patch('jujupy.sleep'):
-                stop_libvirt_domain(URI, dom_name)
-        mock_sp.assert_any_call(['virsh', '-c', URI, 'shutdown', dom_name],
-                                stderr=ANY)
-
-    def test_get_libvirt_domstate(self):
-        URI = 'qemu+ssh://someHost/system'
-        dom_name = 'fido'
-        expected_cmd = ['virsh', '-c', URI, 'domstate', dom_name]
-        with patch('subprocess.check_output') as m_sub:
-            get_libvirt_domstate(URI, dom_name)
-        m_sub.assert_called_with(expected_cmd)
-
-    def test_verify_libvirt_domain_shut_off_true(self):
-        URI = 'qemu+ssh://someHost/system'
-        dom_name = 'fido'
-        with patch('jujupy.get_libvirt_domstate', return_value='shut off'):
-            rval = verify_libvirt_domain_shut_off(URI, dom_name)
-        self.assertTrue(rval)
-
-    def test_verify_libvirt_domain_shut_off_false(self):
-        URI = 'qemu+ssh://someHost/system'
-        dom_name = 'fido'
-        with patch('jujupy.get_libvirt_domstate', return_value='running'):
-            rval = verify_libvirt_domain_shut_off(URI, dom_name)
-        self.assertFalse(rval)
-
-    def test_verify_libvirt_domain_running_true(self):
-        URI = 'qemu+ssh://someHost/system'
-        dom_name = 'fido'
-        with patch('jujupy.get_libvirt_domstate', return_value='running'):
-            rval = verify_libvirt_domain_running(URI, dom_name)
-        self.assertTrue(rval)
-
-    def test_verify_libvirt_domain_running_false(self):
-        URI = 'qemu+ssh://someHost/system'
-        dom_name = 'fido'
-        with patch('jujupy.get_libvirt_domstate', return_value='shut off'):
-            rval = verify_libvirt_domain_running(URI, dom_name)
-        self.assertFalse(rval)

=== modified file 'test_substrate.py'
--- test_substrate.py	2014-11-10 15:53:47 +0000
+++ test_substrate.py	2014-11-11 00:58:39 +0000
@@ -2,6 +2,7 @@
 from unittest import TestCase
 
 from mock import (
+    ANY,
     call,
     patch,
     )
@@ -11,7 +12,13 @@
     translate_to_env,
     )
 from jujupy import SimpleEnvironment
-from substrate import terminate_instances
+from substrate import (
+    get_libvirt_domstate,
+    start_libvirt_domain,
+    stop_libvirt_domain,
+    terminate_instances,
+    verify_libvirt_domain,
+)
 
 
 def get_aws_env():
@@ -93,3 +100,62 @@
                     terminate_instances(env, [])
         self.assertEqual(cc_mock.call_count, 0)
         self.assertEqual(out_mock.write.call_count, 0)
+
+
+class TestLibvirt(TestCase):
+
+    def test_start_libvirt_domain(self):
+        URI = 'qemu+ssh://someHost/system'
+        dom_name = 'fido'
+        with patch('subprocess.check_output',
+                   return_value='running') as mock_sp:
+            with patch('substrate.sleep'):
+                start_libvirt_domain(URI, dom_name)
+        mock_sp.assert_any_call(['virsh', '-c', URI, 'start', dom_name],
+                                stderr=ANY)
+
+    def test_stop_libvirt_domain(self):
+        URI = 'qemu+ssh://someHost/system'
+        dom_name = 'fido'
+        with patch('subprocess.check_output',
+                   return_value='shut off') as mock_sp:
+            with patch('substrate.sleep'):
+                stop_libvirt_domain(URI, dom_name)
+        mock_sp.assert_any_call(['virsh', '-c', URI, 'shutdown', dom_name],
+                                stderr=ANY)
+
+    def test_get_libvirt_domstate(self):
+        URI = 'qemu+ssh://someHost/system'
+        dom_name = 'fido'
+        expected_cmd = ['virsh', '-c', URI, 'domstate', dom_name]
+        with patch('subprocess.check_output') as m_sub:
+            get_libvirt_domstate(URI, dom_name)
+        m_sub.assert_called_with(expected_cmd)
+
+    def test_verify_libvirt_domain_shut_off_true(self):
+        URI = 'qemu+ssh://someHost/system'
+        dom_name = 'fido'
+        with patch('substrate.get_libvirt_domstate', return_value='shut off'):
+            rval = verify_libvirt_domain(URI, dom_name, 'shut off')
+        self.assertTrue(rval)
+
+    def test_verify_libvirt_domain_shut_off_false(self):
+        URI = 'qemu+ssh://someHost/system'
+        dom_name = 'fido'
+        with patch('substrate.get_libvirt_domstate', return_value='running'):
+            rval = verify_libvirt_domain(URI, dom_name, 'shut off')
+        self.assertFalse(rval)
+
+    def test_verify_libvirt_domain_running_true(self):
+        URI = 'qemu+ssh://someHost/system'
+        dom_name = 'fido'
+        with patch('substrate.get_libvirt_domstate', return_value='running'):
+            rval = verify_libvirt_domain(URI, dom_name, 'running')
+        self.assertTrue(rval)
+
+    def test_verify_libvirt_domain_running_false(self):
+        URI = 'qemu+ssh://someHost/system'
+        dom_name = 'fido'
+        with patch('substrate.get_libvirt_domstate', return_value='shut off'):
+            rval = verify_libvirt_domain(URI, dom_name, 'running')
+        self.assertFalse(rval)

